Modules
Structs
- Config
- Configuration struct for quick hull algorithm parameters
- Convex
Hull - Convex
Mesh - Half
Plane - n⋅x≤d n is the normal of the plane d is the offset of the plane x is the point on the plane so the normal of the plane is toward the outside of the convex hull
Enums
- Convex
Hull Construct Error - Represents errors that can occur during convex hull construction.
- Convex
Hull Construct State - Represents the state of convex hull construction.