ConvexHull

Struct ConvexHull 

pub struct ConvexHull {
    pub points: Vec<Point3>,
    pub bounding_planes: Vec<HalfPlane>,
    pub face_indices_start: Vec<u32>,
    pub face_vertex_indices: Vec<u32>,
    pub center: Vec3,
    pub volume: f32,
    pub total_area: f32,
    pub shift_center: Option<Vec3>,
    pub debug: Option<ConvexHullDebugInfo>,
}

Fields

points: Vec<Point3>bounding_planes: Vec<HalfPlane>face_indices_start: Vec<u32>face_vertex_indices: Vec<u32>center: Vec3volume: f32total_area: f32shift_center: Option<Vec3>

The offset vector applied to all points if align-to-center is enabled.

  • If None, align-to-center is disabled, and points remain at their original positions.
  • If Some(Vec3), align-to-center is enabled, and points are shifted by the given vector, meaning the original positions are at pos + shift_center.
debug: Option<ConvexHullDebugInfo>

Implementations

Source

impl<'a> ConvexHull

pub fn get_vertex_indices(&self, face_index: usize) -> &[u32]

pub fn triangle_index_iter(&self) -> impl Iterator<Item = [usize; 3]> + '_

pub fn face_iter(&'a self) -> impl Iterator<Item = &'a [u32]>

Source

impl ConvexHull