pub struct HalfPlane {
pub center: Point3,
pub normal: UnitVec3,
pub offset: f32,
}Expand description
n⋅x≤d n is the normal of the plane d is the offset of the plane x is the point on the plane so the normal of the plane is toward the outside of the convex hull
Fields
center: Point3normal: UnitVec3offset: f32Auto Trait Implementations
impl Freeze for HalfPlane
impl RefUnwindSafe for HalfPlane
impl Send for HalfPlane
impl Sync for HalfPlane
impl Unpin for HalfPlane
impl UnwindSafe for HalfPlane